@@ -3,7 +3,7 @@
 #include <string.h>
 #include <stdio.h>
 #include <ctype.h>
-#include "macro.h"
+#include "macro.h"    //18/12/8
 
 int  wnb, wc, ct;
 int  te, quo;
