@@ -2,7 +2,7 @@
 #include <string.h>
 #include <stdio.h>
 #include <ctype.h>
-#include "macro.h"
+#include "macro.h"    //18/12/8
 
 extern FILE *prcs, *dbg;
 extern int wnb, wc;
