@@ -280,6 +280,9 @@ int  ppt, *cs;
 	if(ct == 9){ ct = 0;	continue; }
 	jw = (char*)index(ejw, ';');
 	ptcpy(egw, ejw, jw);
+
+	// add_debug(ejw, nx);
+
 	if(strlen(wdx) > strlen(egw)) goto NTT;
 	jt = (char*)index(jw+1, ';');
 	ptcpy(jpw, jw+1, jt);
@@ -310,9 +313,11 @@ int  ppt, *cs;
 	rwc = wdw[strlen(egw)];
 	if(rwc != ' ' && rwc != '\0' && rwc != '-' && rwc != '.' && zkc != 'h')
 	  goto NTT;
+
 	OKYAKU:
-// printf("--- diclook1 --- ejw = %s \n", ejw);
+ if(Dbg == 'Y') fprintf(dbg, "--- diclook --- ejw = %s \n", ejw); // 
 	yakSaiyo(jpw,egw,zkw,wdx,wdp);
+
 	NTT:
 	cutoff(ejr, 0, strlen(ejw));
       }
@@ -327,12 +332,16 @@ char ejr[];
 {
     long ptl;
     char *ptc;
+    int ret;
     ptl = (long)(ppt-1)* Size;
     rewind(ejd);
-    if(fseek(ejd, ptl, 0)){
+    if(fseek(ejd, ptl, SEEK_SET)){    // 0 -> SEEK_SET
       printf("seek error\n");	exit(1);
     }
-    fread(ejr, Size-4,1, ejd);
+    ret = fread(ejr, Size-4,1, ejd);
+    if(ret != 1){
+      return(1); // error
+    }
     fscanf(ejd, "%4d", nx);
     *(ejr+ Size-5) = '\0';
     if(ptc = (char*)rindex(ejr, ':')) *(ptc+1) = '\0';
@@ -448,6 +457,8 @@ int  *cs;
 	if(*rpt == 'e') continue;
   if(Dbg == 'Y') fprintf(dbg, "--- Conj cs=3 ---  wd = %s dums = %s *rpt = %c \n", wd, dums, *rpt);
         if(!strcmp(wd, "propelled") || !strcmp(wd, "cancelled")
+	// || strcmp(wd+strlen(wd)-4, "lled") == 0    // annulled compelled
+	|| !strcmp(wd, "compelled")
         || !strcmp(wd, "repelled")  || !strcmp(wd, "annulled")){
           *rpt = '\0';
 	  zkc = 'p';	caj[0][0] = '3';	return;
@@ -759,6 +770,7 @@ char egw[WordLen], wdw[SentLen], wdp[];
     sp = 0;	lnw++;
     while(sp1 = ninstrc(sp+1, egw, ' ')) sp = sp1;
  if(Dbg == 'Y') fprintf(dbg, "--- tailConj --- sp = %d egw = %s  wdw = %s \n", sp, egw, wdw);
+
     if(sp && strcmp(egw, wdw)){
       if(strstr(egw,"oneself") && (strstr(wdw,"self") || strstr(wdw,"selves"))){
 	jo = instr(egw, "oneself");
