@@ -793,13 +793,14 @@ find()
     }
 }
 
+// ̓t@C̃f[^̏ pP:XP:: X͕iԍ
 copy()
 {
     FILE *fp;
     int  i, j, jz, ppt, pt0, nx, ia, in, iz, nxs[RecNb], eq, ln, re;
     char file[32], line[100], wd1[WordLen];
     char *p0, *pt1, *pt2;
-    puts("\n͂t@C̃^Cv@IƂ END łB");
+    puts("\n͂t@C(ex. WDREG)̃^Cv@IƂ END łB");
     printf("̓t@C = ");	file[0] = '\0';
     while(! isalpha(file[0])) gets(file);
     if(strcmp(file, "END")==0) return;
@@ -811,7 +812,7 @@ copy()
       ptcpy(wd, line, p0);
       pt1 = (char*)index(p0+1, ':');	ptcpy(jwd, p0+1, pt1);
       pt2 = (char*)index(pt1+1, ':');	ptcpy(zwd, pt1+1, pt2);
-      ptcpy(jwd+1, pt2+1, line+strlen(line)-1);
+      //      ptcpy(jwd+1, pt2+1, line+strlen(line)-1);
       color_red;	printf("%-20s ", wd);	color_white;
       printf("%-20s %-20s \n", jwd, zwd);
       ppt = ptcal(dics, dic);	re = 0;
