@@ -5,7 +5,7 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <ctype.h>
-#include "macro.h"
+#include "macro.h"    // 18/12/8
 
 char *dir = "/usr/home/murase/c/yak/";
 
@@ -93,7 +93,7 @@ char *argv[];
 //    sprintf(ejdic, "%sEJDIC.HON", dir);
     strcpy(ejdic, "EJDIC.HON");
 //    ejd = fopen("EJDIC.HON", "r");
-    ejd = fopen(ejdic, "r");
+    ejd = fopen(ejdic, "rb");
     setUp();
     zbClear();
     if(Dbg == 'Y'){ dbg = fopen("DEBUG.YAK", "w");
@@ -104,6 +104,10 @@ char *argv[];
 //    sprintf(process, "%sPROCESS.YAK", dir);
 //    prcs = fopen("PROCESS.YAK", "w");
     if(LOG == 'Y') prcs = fopen(process, "w");
+
+    //    ini_count();  // ł΂
+    //    ini_debug();  // 19/2/11
+
     mai1:
     printf("\n");
     // expression()̒l'1'(擪'<')̎
@@ -125,6 +129,7 @@ char *argv[];
     }
 
     if(BOTH == 'Y') fprintf(fpout, "%s<BR> \n", egs);  // \̏ꍇ
+    //    else goto MAI2; // 12/17
   
   MAIN3:
     printf("\n");	puts(egs);
@@ -135,6 +140,7 @@ char *argv[];
     if(quo == 0 && script == 0 && *jps != '<') fprintf(fpout, "\n");
     if(buf[0] == ';' || buf[0] == ',') goto mai1;
     goto mai1;
+
   MAI2:
     printf("End of file reached\n");
     if(LOG == 'Y'){ fclose(prcs);
@@ -142,8 +148,9 @@ char *argv[];
     }
     if(Dbg == 'Y'){ fclose(dbg); fclose(wdr);    }
     fclose(fpin);	fclose(fpout);	fclose(ejd);
+
     if(existence == 0){ printf("Sentence not exist!\n");  exit(1); }
-    resave();
+    //    resave();
     exit(0);
 }
 
@@ -592,6 +599,7 @@ expression(){
 	else strcpy(wdw, wdh);
 //  printf("--- expression1 --- wc = %d  wdp = %s  wdw = %s  wdh = %s \n",wc, wdp,wdw,wdh);
 //        if(*wdw == '<') return(1);
+
 	ppt = ptcal(dics,dic,wdw);
         if(ppt == 0) break;
 	diclook(ppt, &cs);
@@ -654,9 +662,9 @@ int  *cs;
     int  i, ln, kakf = 0;
     char kd[WordLen], *gobi, cac, *ptc;
     cac = caj[0][0];
- if(Dbg == 'Y') fprintf(dbg, "--- kakut --- caj[0] = %s  zkc = %c \n", caj[0], zkc);
+ if(Dbg == 'Y') fprintf(dbg, "--- kakut --- caj[0] = %s  zkc = %c cs = %d \n", caj[0], zkc, cs);
     if(cac == '\0'){
- if(Dbg == 'Y') fprintf(dbg, "--- kakut --- caj[0] = %s  zkc = %c \n", caj[0], zkc);	return;
+ if(Dbg == 'Y') fprintf(dbg, "--- kakut --- cac = 0  caj[0] = %s  zkc = %c \n", caj[0], zkc);	return;
     }
     ct = 0;
     if(cac == '0' || cac == '?' || cac == '!' || cac == '|'){
@@ -770,6 +778,7 @@ int  *cs;
       if(kakf != 0) strcpy(wdx, wd);
       return;
     }
+ if(Dbg == 'Y') fprintf(dbg, "--- kakut --- kd = %s wdw = %s cs = %d \n", kd, wdw, cs);
     if(strcmp(kd, wdw) == 0){ *wdh = '\0';	*wdp = '\0'; }
     else{
       printf("wdw == error!!  kd = %s  wdw = %s  wd = %s \n",kd,wdw,wd);
