@@ -34,15 +34,30 @@ wdcpy(char *st1, char *st2)
     *st1 = '\0';
 }
 
+// \̊댯
+//cutoff2(a, x, i)
+//char *a;
+//int  x, i;
+//{
+//    int  ln;
+//    char *b;
+//    ln = strlen(a);
+//    if(x < ln){
+//      b = a+x+i;	*(a+x) = '\0';
+//      if(ln > x+1) strcat(a, b);       // 
+//    }
+//}
+
 cutoff(a, x, i)
 char *a;
-int  x, i;
+int  x,  i;
 {
     int  ln;
-    char *b;
+    char b[2000];
     ln = strlen(a);
     if(x < ln){
-      b = a+x+i;	*(a+x) = '\0';
+      strcpy(b, a+x+i);
+      *(a+x) = '\0';
       if(ln > x+1) strcat(a, b);
     }
 }
@@ -282,7 +297,7 @@ int  *no;
 char wdh[];
 {
     int  i, j, ln;
-    char dums[8], commt[SentLen], cmt2[SentLen], dmy[5], *pt, *pt1;
+    char dum[8], commt[SentLen], cmt2[SentLen], dmy[15], *pt, *pt1;
  if(Dbg == 'Y') fprintf(dbg, "--- predit --- wdh = %s \n", wdh);
     if(*wdh == ' ') ptcut(wdh, 1);
     // em_bVň͂܂Ă镶ꍇ
@@ -311,6 +326,8 @@ char wdh[];
       if(pt = (char*)strstr(pt, "f")){ ptreplace(pt, 2, "\'"); pt = wdh; }
     for(pt = wdh; pt != NULL; )
       if(pt = (char*)strstr(pt, "")){ ptreplace(pt, 2, "\\"); pt = wdh; }
+    for(pt = wdh; pt != NULL; )
+      if(pt = (char*)strstr(pt, "Health, Labor and Welfare Ministry")){ ptreplace(pt, 34, "Mhlw"); pt = wdh; }
     for(pt = wdh; pt != NULL; )
       if(pt = (char*)strstr(pt, "Why don't we")){ ptreplace(pt, 12, "Shall we"); pt = wdh; }
     for(pt = wdh; pt != NULL; )
@@ -409,7 +426,15 @@ char wdh[];
         else{ ptreplace(wdh+i, 1, "and");	j += 2; }
       }
     }
-    ln = strlen(wdh);   j = ln;
+
+    // ','̏ꍇ
+    for(pt = wdh; pt != NULL; )
+      if((pt = (char*)strstr(pt, ", ")) && *(pt-1) != ' '){ ptinsert(pt, " "); pt=pt+2; }
+
+  if(Dbg == 'Y') fprintf(dbg, "--- predit ---,--- wdh = %s \n", wdh);
+
+
+  /*    ln = strlen(wdh);   j = ln;
     for(i = ln-2; i > 0; i--){
       if(wdh[i] == ',' && i >= ln-4){
 	insertc(wdh, i+1, ' ', j++);
@@ -421,7 +446,7 @@ char wdh[];
 	  insertc(wdh, i, ' ', j++);
 	}
       }
-    }
+    }*/
     ln = strlen(wdh);
     for(i = ln-1; i > 0; i--)
       if(wdh[i] == ' ' && wdh[i+1] == ' ') cutoff(wdh, i, 1);
@@ -454,8 +479,8 @@ char wdh[];
 //      if(wdh[i] != ' ' && wdh[i] != '\"') break;
 //      if(wdh[i] == ' '){ wdh[i] = '\0';	j--; }
     }
-    ln =strlen(wdh);	right(wdh, dums, 3);
-    if(strcmp(dums,". \"") == 0) ptinsert(wdh+ln-3, " ");
+    ln =strlen(wdh);	right(wdh, dum, 3);
+    if(strcmp(dum,". \"") == 0) ptinsert(wdh+ln-3, " ");
 
     ln = strlen(wdh);
     j = ln;	ct = 0;
@@ -524,6 +549,7 @@ char wdh[];
       *pt = '%';
       ptinsert(pt, " ");
     }
+    // P-P̏ꍇA-spaceɕϊ
     for(pt = wdh; pt != 0; ){
       if((pt = (char*)strstr(wdh, "-")) && strncmp(pt, "--", 2))
         ptreplace(pt, 1, " ");
@@ -555,6 +581,12 @@ char wdh[];
     while(*wdh == ' ') ptcut(wdh, 1);
 }
 
+predit2(wdh, no)
+int  *no;
+char wdh[];
+{
+}
+
 /*------- posted ------------------------------------------*/
 
 siage(jps)
@@ -567,7 +599,7 @@ char jps[];
     if(c0 == '0' || c0 == '?' || c0 == '!' || c0 == '\0') ct = 0;
     jps[0] = '\0';
     for(i = 0; i <= wnb; i++){
- if(Dbg == 'Y') fprintf(dbg, "--- siage --- %s \n", cj[i]);
+      if(Dbg == 'Y') fprintf(dbg, "--- siage --- i = %d %s \n", i, cj[i]);
       ptcut(cj[i], 1);
       while((pt1 = (char*)index(cj[i], '(')) && (pt2 = (char*)index(pt1+1, ')'))){
         ptptcut(pt1, pt2);
@@ -640,3 +672,51 @@ char StrnToLower(char *s, int n)
   return(*s);
 }
 
+// |󌋉ʂoȂƂł΂ׂ̈̃JE^
+
+int ini_count(void){
+  FILE *fp;
+  int count;
+  char buf[16];
+
+  fp = fopen("COUNTER", "w");
+
+  count = 0;
+  fseek(fp, 0, SEEK_SET);
+  fprintf(fp, "%d", count);
+  fclose(fp);
+  return count;
+}
+
+int get_count(void){
+  FILE *fp;
+  int count;
+  char buf[16];
+
+  fp = fopen("COUNTER", "r+");
+  fgets(buf, 16, fp);
+  count = atoi(buf) + 1;
+  fseek(fp, 0, SEEK_SET);
+  fprintf(fp, "%d", count);
+  fclose(fp);
+  return count;
+}
+
+int ini_debug(void){
+  FILE *fp;
+
+  fp = fopen("DEBUG", "w");
+
+  fclose(fp);
+  return;
+}
+
+int add_debug(char *str, int num){
+  FILE *fp;
+
+  fp = fopen("DEBUG", "a");
+
+  fprintf(fp, "%s %d \n", str, num);
+  fclose(fp);
+  return;
+}
