@@ -336,6 +336,10 @@ int  *comma;
 // if(Dbg == 'Y') fprintf(dbg, "--- position --- sj = %s pbun = %s \n", sj, pbun);
 	if(sj[0] == '\0') return;
     }
+    if(strstr(pbun, "EO")){
+// if(Dbg == 'Y') fprintf(dbg, "--- position --- oj = %s pbun = %s \n", oj, pbun);
+	if(oj[0] == '\0') return;
+    }
     if(strstr(pbun, "FK")){
       ct = 0;
 //      bfukuCk(comma);
