@@ -264,7 +264,7 @@ char *pt;
       ninsyo(md[i], mz[i], md[j], mz[j]);    return;
     }
     if(strncmp(cmd, "&", 1) == 0){
-      ninsyo(md[i], mz[i], cmd, mz[i]);    return;
+      ninsyo(md[i], mz[i], cmd, "" );    return; // 17/3/13
     }
     if(strncmp(cmd, "ONE&", 4) == 0){
       pcm = (char*)strstr(md[i]+1, "one");
