@@ -1,7 +1,7 @@
 /*  macro.h  */
 #define	WordNumb	70
-#define SentLen		400
-#define JSentLen	420
+#define SentLen		600   //400
+#define JSentLen	650   //420
 #define WordLen		90    //45
 #define JWordLen	50
 #define ZokuLen		40
