@@ -1,7 +1,7 @@
 #include <string.h>
 #include <stdio.h>
 #include <ctype.h>
-#include "macro.h"
+#include "macro.h"   //18/12/8
 
 
 extern FILE *prcs, *dbg;
@@ -52,7 +52,8 @@ tekyk(){
 	      }
 	      pwct = 0;
 	      if((tekpt = fopen(Tekiyakufile, "r")) == '\0'){
-		printf("Teki I[vł܂łB");	exit(1);
+		printf("Teki I[vł܂łB");
+		//  exit(1);
 	      }
 	      while((f=(int)fgets(ptek, 192, tekpt))){ ct = 0;
 		ptek[strlen(ptek)-1] = '\0';
@@ -194,6 +195,7 @@ char tst[];
     jc = tst[0];	tc = tst[1];
     for(i = comma-1; i >= 0; i--){
       if(aj[i][0][0] == jc && aj[i][1][0] == '\0' && index(az[i][0], tc)){
+ if(Dbg == 'Y') fprintf(dbg, "--- f1jt --- aj[%d][0] = %s az[%d][0] = %s \n", i, aj[i][0], i, az[i][0]);
 	*jtpt = i;	return;
       }
     }
@@ -343,7 +345,7 @@ char tst[], *pj;
 	  }
 	  else{
 	 printf("\n Lack of 'R' information on %s in the dictionary.\n",en[ss]);
-	    exit(1);
+	 //    exit(1);
 	  }
 	}
       }
@@ -775,7 +777,7 @@ char tcd[];
 //      if(Dbg == 'Y' || Dbg == 'y')
 //	fprintf(dbg, "\n %s \n     %s ; %s \n", ptek, caj[0], caj[*j]);
 //      else
-      if(LOG == 'Y') fprintf(prcs, "\n %s \n     %s ; %s \n", ptek, caj[0], caj[*j]);
+      if(LOG == 'Y') fprintf(prcs, "\n ptek = %s \n     %s ; %s \n", ptek, caj[0], caj[*j]);
       if((*sg == *tcd && shsw == 0) || (*sg != *tcd && shsw)) fc = *tcd;
       else fc = tcd[1];
       ct = 30;
